@@ -63,19 +63,19 @@ class AcidBasePair(object):
 #: The default list of AcidBasePairs, sorted from strongest to weakest. This list is derived from the Food and Drug
 #: Administration Substance Registration System Standard Operating Procedure guide.
 ACID_BASE_PAIRS = (
-    AcidBasePair('-OSO3H', 'OS(=O)(=O)[O;H]', 'OS(=O)(=O)[O-]'),
-    AcidBasePair('–SO3H', '[!O]S(=O)(=O)[O;H]', '[!O]S(=O)(=O)[O-]'),
-    AcidBasePair('-OSO2H', 'O[S;D3](=O)[O;H]', 'O[S;D3](=O)[O-]'),
-    AcidBasePair('-SO2H', '[!O][S;D3](=O)[O;H]', '[!O][S;D3](=O)[O-]'),
-    AcidBasePair('-OPO3H2', 'OP(=O)([O;H])[O;H]', 'OP(=O)([O;H])[O-]'),
-    AcidBasePair('-PO3H2', '[!O]P(=O)([O;H])[O;H]', '[!O]P(=O)([O;H])[O-]'),
-    AcidBasePair('-CO2H', 'C(=O)[O;H]', 'C(=O)[O-]'),
-    AcidBasePair('thiophenol', 'c[S;H]', 'c[S-]'),
-    AcidBasePair('(-OPO3H)-', 'OP(=O)([O;H])[O-]', 'OP(=O)([O-])[O-]'),
-    AcidBasePair('(-PO3H)-', '[!O]P(=O)([O;H])[O-]', '[!O]P(=O)([O-])[O-]'),
-    AcidBasePair('phthalimide', 'O=C2c1ccccc1C(=O)[N;H]2', 'O=C2c1ccccc1C(=O)[N-]2'),
-    AcidBasePair('CO3H (peracetyl)', 'C(=O)O[O;H]', 'C(=O)O[O-]'),
-    AcidBasePair('alpha-carbon-hydrogen-nitro group', 'O=N(O)[C;H]', 'O=N(O)[C-]'),
+    AcidBasePair('-OSO3H', 'OS(=O)(=O)[OH]', 'OS(=O)(=O)[O-]'),
+    AcidBasePair('–SO3H', '[!O]S(=O)(=O)[OH]', '[!O]S(=O)(=O)[O-]'),
+    AcidBasePair('-OSO2H', 'O[SD3](=O)[OH]', 'O[SD3](=O)[O-]'),
+    AcidBasePair('-SO2H', '[!O][SD3](=O)[OH]', '[!O][SD3](=O)[O-]'),
+    AcidBasePair('-OPO3H2', 'OP(=O)([OH])[OH]', 'OP(=O)([OH])[O-]'),
+    AcidBasePair('-PO3H2', '[!O]P(=O)([OH])[OH]', '[!O]P(=O)([OH])[O-]'),
+    AcidBasePair('-CO2H', 'C(=O)[OH]', 'C(=O)[O-]'),
+    AcidBasePair('thiophenol', 'c[SH]', 'c[S-]'),
+    AcidBasePair('(-OPO3H)-', 'OP(=O)([OH])[O-]', 'OP(=O)([O-])[O-]'),
+    AcidBasePair('(-PO3H)-', '[!O]P(=O)([OH])[O-]', '[!O]P(=O)([O-])[O-]'),
+    AcidBasePair('phthalimide', 'O=C2c1ccccc1C(=O)[NH]2', 'O=C2c1ccccc1C(=O)[N-]2'),
+    AcidBasePair('CO3H (peracetyl)', 'C(=O)O[OH]', 'C(=O)O[O-]'),
+    AcidBasePair('alpha-carbon-hydrogen-nitro group', 'O=N(O)[CH]', 'O=N(O)[C-]'),
     AcidBasePair('-SO2NH2', 'S(=O)(=O)[NH2]', 'S(=O)(=O)[NH-]'),
     AcidBasePair('-OBO2H2', 'OB([OH])[OH]', 'OB([OH])[O-]'),
     AcidBasePair('-BO2H2', '[!O]B([OH])[OH]', '[!O]B([OH])[O-]'),
@@ -84,18 +84,18 @@ ACID_BASE_PAIRS = (
     AcidBasePair('(-OBO2H)-', 'OB([OH])[O-]', 'OB([O-])[O-]'),
     AcidBasePair('(-BO2H)-', '[!O]B([OH])[O-]', '[!O]B([O-])[O-]'),
     AcidBasePair('cyclopentadiene', '[CH2]1C=CC=C1', '[C-]1C=CC=C1'),
-    AcidBasePair('-CONH2', 'C(=O)[NH2]', 'C(=O)[N;H;-]'),
+    AcidBasePair('-CONH2', 'C(=O)[NH2]', 'C(=O)[NH-]'),
     AcidBasePair('imidazole', 'c1cnc[n]1', 'c1cnc[n-]1'),
     AcidBasePair('-OH', '[CX4][OH]', '[CX4][O-]'),
     AcidBasePair('alpha-carbon-hydrogen-keto group', 'O=C[CH]', 'O=C[C-]'),
     AcidBasePair('alpha-carbon-hydrogen-acetyl ester group', 'OC(=O)[CH]', 'OC(=O)[C-]'),
     AcidBasePair('sp carbon hydrogen', 'C#[CH]', 'C#[C-]'),
     AcidBasePair('alpha-carbon-hydrogen-sulfone group', 'CS(=O)(=O)C[CH]', 'CS(=O)(=O)C[C-]'),
-    AcidBasePair('alpha-carbon-hydrogen-sulfoxide group', 'C[S;D3](=O)C[CH]', 'C[S;D3](=O)C[C-]'),
-    AcidBasePair('-NH2', '[CX4][NH2]', '[CX4][N;H;-]'),
-    AcidBasePair('benzyl hydrogen', 'c[C;D4;H]', 'c[C;D3;-]'),
-    AcidBasePair('sp2-carbon hydrogen', '[CX3;H]', '[CX3;-]'),
-    AcidBasePair('sp3-carbon hydrogen', '[CX4;H]', '[CX3-]'),
+    AcidBasePair('alpha-carbon-hydrogen-sulfoxide group', 'C[SD3](=O)C[CH]', 'C[SD3](=O)C[C-]'),
+    AcidBasePair('-NH2', '[CX4][NH2]', '[CX4][NH-]'),
+    AcidBasePair('benzyl hydrogen', 'c[CD4H]', 'c[CD3-]'),
+    AcidBasePair('sp2-carbon hydrogen', '[CX3]=[CX3H]', '[CX3]=[CX2-]'),
+    AcidBasePair('sp3-carbon hydrogen', '[CX4H]', '[CX3-]'),
 )
 
 
