@@ -1,5 +1,13 @@
 # -*- coding: utf-8 -*-
-"""utils.py"""
+"""
+molvs.utils
+~~~~~~~~~~~
+
+This module contains miscellaneous utility functions.
+
+:copyright: Copyright 2014 by Matt Swain.
+:license: MIT, see LICENSE file for more details.
+"""
 
 from __future__ import print_function
 from __future__ import unicode_literals
